@@ -27,6 +27,7 @@
 #include <fcntl.h>
 #endif
 #include "flash.h"
+#include "programmer.h"
 #include "hwaccess.h"
 
 #if !(IS_LINUX || IS_MACOSX || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__) || defined(__DJGPP__) || defined(__LIBPAYLOAD__) || defined(__sun) || defined(__gnu_hurd__))
@@ -223,7 +224,7 @@ struct undo_mmio_write_data {
 	};
 };
 
-int undo_mmio_write(void *p)
+static int undo_mmio_write(void *p)
 {
 	struct undo_mmio_write_data *data = p;
 	msg_pdbg("Restoring MMIO space at %p\n", data->addr);
